*************************************************************************
*                                                                         
* Program name: DLQCLEAR                                                  
*                                                                         
* Description: Sample application prpogram for MQSeries for VSE/ESA to   
*              demonstrate the processing of a DEAD LETTER QUEUE          
*                                                                         
*  Statement:  Licensed Materials - Property of IBM                       
*                                                                         
*              MQSeries SupportPac MS21                                   
*              (C) Copyright IBM Corp. 1999                               
*                                                                         
*************************************************************************
*                                                                         
* Function:                                                               
*                                                                         
*   This is a simple COBOL application which can be used to process      
*   messages in the dead letter queue.                                    
*                                                                         
*                                                                         
*                                                                         
* Change history:                                                         
*                                                                         
* V1.0   13 December 1999  SD   Initial release                             
*                                                                         
*========================================================================
* Module Name: DLQCLEAR.COBOL                                             
*========================================================================
* Program usage:                                                          
*                                                                         
*  This program is provided as a sample only which allows the             
*  MQ VSE Dead Letter Queue (DLQ) to be purged.                           
*                                                                         
*  Messages are read from the DLQ and the original target                 
*  queue is evaluated to see if the queue is now valid                    
*  and available. If the target queue is available                        
*  then the message is written to that queue. Otherwise the               
*  message is written to a alternate DLQ which must be                    
*  pre-defined by the user.                                               
*                                                                         
* Remarks:                                                                
*                                                                         
*  When messages are written to the original target queue                 
*  they are placed at the end of the queue and no allowance               
*  is made for sequence position. ie. If the user data has                
*  its own sequence information within it then great care                 
*  should be taken when using this program and processing the             
*  target queue.                                                          
*                                                                         
* Invocation format:                                                      
*                                                                         
*    txid DLQname DLQalternatename $nnnn                                 
*                                                                         
*    where txid             = transaction id defined by user to           
*                             invoke this program.                        
*                                                                         
*          DLQname          = name of the system DLQ.                     
*                                                                         
*          DLQalternatename = name of an alternate DLQ which must         
*                             be defined by the user.                     
*                                                                         
*          nnnn             = numeric value in seconds after which        
*                             this transaction (txid) will                
*                             automatically be restarted.                 
*                                                                         
*                             Please note that this restart function      
*                             is currently commented out and if the       
*                             user wishes to enable this facility then    
*                             the comments in paragraph 0000-RESTART      
*                             must be removed.                            
*                                                                         
* Error Conditions:                                                       
*                                                                         
*  For all error conditions the program attempts to write messages        
*  to the System Log message queue and then terminates. The program       
*  assumes that the name of the System Log is 'SYSTEM.LOG'. This may      
*  be changed by making appropriate amendments to paragraph               
*  9999-PUT-TO-LOG-Q of the code.                                         
*                                                                         
*************************************************************************
 IDENTIFICATION DIVISION.                                         
 PROGRAM-ID.    DLQCLEAR.                                         
 AUTHOR.        IBM.                                              
 ENVIRONMENT DIVISION.                                            
 CONFIGURATION SECTION.                                           
 DATA DIVISION.                                                   
 WORKING-STORAGE SECTION.                                         
*------------------------------------------------------------*    
                                                                  
 01  FILLER                         PIC X(40) VALUE               
                   'DLQCLEAR WORKING STORAGE STARTS HERE ==>'.    
                                                                  
 01  WS-VERSION.                                                  
     05  FILLER                     PIC X(30)                     
     VALUE 'DLQCLEAR VERSION 1.0'.                                
                                                                  
*--                                                               
 01  WS-WORK-FIELDS.                                              
     05  WS-VALID-ACTUAL-QUEUE      PIC X.                        
         88 VALID-ACTUAL-QUEUE      VALUE 'Y'.                    
         88 INVALID-ACTUAL-QUEUE    VALUE 'N'.                    
     05  WS-MSG-PROCESS-FLAG        PIC X.                        
         88 MSG-PROCESSED-OK        VALUE 'Y'.                    
         88 MSG-PROCESSED-NOK       VALUE 'N'.                    
     05  WS-DLQ-TERMINATION-FLAG    PIC X  VALUE SPACE.           
         88 OTHER-FINISH-CONDITION  VALUE 'O'.                    
     05  WS-TRANSID                 PIC X(4).                     
     05  WS-TIMEDELAY               PIC X(4).                     
     05  WS-TIMEDELAYN REDEFINES WS-TIMEDELAY                     
                                    PIC 9(4).                     
     05  WS-DELAY                   PIC S9(8) COMP.               
*--  QM General fields                                            
     05  WS-QM-NAME-CONNECT         PIC  X(48).                   
     05  WS-HCONN-ADDR-AREA.                                      
         07  WS-HCONN-VALUE         POINTER.                      
     05  WS-HCONN-CCODE             PIC S9(8) COMP.               
     05  WS-HCONN-RCODE             PIC S9(8) COMP.               
*--  DLQ Source Q values.                                         
     05  SOURCE-DLQ-NAME            PIC X(48).                    
     05  SRC-HOBJ-ADDR-AREA.                                      
         07  SRC-HOBJ-VALUE         POINTER.                      
     05  SRC-HOBJ-ADDR-AREA-REPLY.                                
         07  SRC-HOBJ-VALUE-REPLY   POINTER.                      
     05  SRC-CCODE-ADDR-AREA.                                     
         07  SRC-CCODE-VALUE        PIC S9(8) COMP.               
     05  SRC-RCODE-ADDR-AREA.                                     
         07  SRC-RCODE-VALUE        PIC S9(8) COMP.               
     05  SRC-Q-OPEN-OPTIONS.                                      
         07  SRC-Q-OPEN-OPTIONS-VALUE    PIC S9(8) COMP.          
*--  DLQ Target Q values                                          
     05  TARGET-DLQ-NAME            PIC X(48).                    
     05  TGT-HOBJ-ADDR-AREA.                                      
         07  TGT-HOBJ-VALUE         POINTER.                      
     05  TGT-HOBJ-ADDR-AREA-REPLY.                                
         07  TGT-HOBJ-VALUE-REPLY   POINTER.                      
     05  TGT-CCODE-ADDR-AREA.                                     
         07  TGT-CCODE-VALUE        PIC S9(8) COMP.               
     05  TGT-RCODE-ADDR-AREA.                                     
         07  TGT-RCODE-VALUE        PIC S9(8) COMP.               
     05  TGT-Q-OPEN-OPTIONS.                                      
         07  TGT-Q-OPEN-OPTIONS-VALUE    PIC S9(8) COMP.          
*--  DLQ Inquiry Q values                                         
     05  INQ-HOBJ-ADDR-AREA.                                      
         07  INQ-HOBJ-VALUE         POINTER.                      
     05  INQ-HOBJ-ADDR-AREA-REPLY.                                
         07  INQ-HOBJ-VALUE-REPLY   POINTER.                      
     05  INQ-CCODE-ADDR-AREA.                                     
         07  INQ-CCODE-VALUE        PIC S9(8) COMP.               
     05  INQ-RCODE-ADDR-AREA.                                     
         07  INQ-RCODE-VALUE        PIC S9(8) COMP.               
     05  INQ-Q-OPEN-OPTIONS.                                      
         07  INQ-Q-OPEN-OPTIONS-VALUE    PIC S9(8) COMP.          
*--  Repeat field values.                                         
*--  Input parameter values.                                      
     05  WS-PASSED-INFO             PIC X(512).                   
     05  WS-PASS-MSG-LENGTH         PIC S9(4) COMP.               
*--                                                               
     05  WS-STARTCODE                PIC  XX   VALUE SPACE.       
       88  START-WITH-DATA          VALUE 'SD'.                   
       88  START-WITH-NO-DATA       VALUE 'S '.                   
       88  START-FROM-TERM          VALUE 'TD'.                   
                                                                  
*---------------------------------------------------------------* 
*-- Fields required for Q Name inquiry.                           
 01  MQI-SECTOR-COUNT.                                            
    05 WS-SECTOR-COUNT             PIC S9(8) COMP VALUE ZERO.     
 01  MQI-SECTOR.                                                  
    05  MQI-SECTOR-ENTRY   OCCURS 40 TIMES                        
                                   PIC S9(8) COMP.                
                                                                  
 01  MQI-IN-ATTR-COUNT.                                           
    05 WS-IN-ATTR-COUNT            PIC S9(8) COMP VALUE +40.      
 01  MQI-IN-ATTR.                                                 
    05 MQI-IN-ATTR-ENTRY   OCCURS 40 TIMES                        
                                   PIC S9(8) COMP.                
                                                                  
 01  WS-DLQ-BUFFER-ACTUAL          PIC S9(8) COMP.                
 01  WS-DLQ-BUFFER-LEN             PIC S9(8) COMP.                
 01  WS-DLQ-OFFSET                 PIC S9(8) COMP.                
                                                                  
 01  WS-DLQ-BUFFER.                                               
    05  FILLER                     PIC X OCCURS 32767.            
 01  WS-DLQ-DLH-DEF REDEFINES WS-DLQ-BUFFER.                      
    03  WS-DLQ-HEADER.                                            
        05  FILLER                 PIC X(12).                     
        05  SRC-DLQ-TARGET         PIC X(48).                     
        05  FILLER                 PIC X(112).                    
    03  SRC-DLQ-MSG                PIC X(32595).                  
                                                                  
*----------------------------------------------------------------*
 01  ERROR-ERROR-SAVE-FLDS.                                       
     05 ERROR-DFHEIV0.                                            
        10 ERROR-DFHEIV0-BYTE   PIC X(1) OCCURS 31 TIMES.         
           88 ERROR-DFHEIV0-NUMERIC  VALUE '0' THRU '9'.          
                                                                  
     05 ERROR-S-EIBFN           PIC X(2) VALUE LOW-VALUES.        
     05 ERROR-S-EIBFN-BIN REDEFINES ERROR-S-EIBFN PIC S9(4) COMP. 
                                                                  
     05 ERROR-S-EIBRCODE.                                         
        10 ERROR-S-EIBRCODE-B2  PIC 9(4) COMP VALUE ZEROS.        
        10 ERROR-S-EIBRCODE-B4  PIC 9(8) COMP VALUE ZEROS.        
                                                                  
     05 ERROR-S-EIBRSRCE        PIC X(8)       VALUE SPACES.      
     05 ERROR-S-EIBRESP         PIC S9(8) COMP VALUE ZERO.        
     05 ERROR-S-EIBRESP2        PIC S9(8) COMP VALUE ZERO.        
                                                                  
 01  HEX-CONVERSION-WORKAREAS.                                    
     05  FILLER PIC X(4) VALUE 'HEX:'.                            
     05  HEX-BIN-WRK        COMP.                                 
         10  HEX-BINARY-WORD     PIC 9(8) VALUE ZERO.             
         10  HEX-DIGIT-INDX      PIC S9(4) VALUE ZERO.            
         10  HEX-INDX            PIC S9(4) VALUE ZERO.            
         10  HEX-CHAR-LEN        PIC S9(4) VALUE ZERO.            
                                                                  
     05  HEX-CHAR-WORD.                                           
         10  HEX-CHAR-BYTE       PIC X(1)   OCCURS 8 TIMES.       
                                                                  
     05  HEX-DIGITS              PIC X(16)                        
                                  VALUE '0123456789ABCDEF'.       
     05  HEX-DIGITSX REDEFINES HEX-DIGITS.                        
         10  HEX-DIGIT           PIC X(1) OCCURS 16 TIMES.        
                                                                  
*-------------------------------------------------------------*   
 01  WS-ERROR-MESSAGES.                                           
     05 WS-ERR-DISPLAY-LEN         PIC S9(8) COMP.                
     05 WS-ERR-DISPLAY             PIC X(80).                     
     05 WS-ERR-DISPLAY1.                                          
        10 FILLER                PIC X(9) VALUE 'EIBFN:'.         
        10 ERROR-DEBUG-EIBFN     PIC X(4) VALUE SPACES.           
        10 FILLER                PIC X(4) VALUE SPACES.           
        10 FILLER                PIC X(14) VALUE '   EIBRCODE: '. 
        10 ERROR-DEBUG-EIBRCODE-1  PIC X(4) VALUE SPACES.         
        10 ERROR-DEBUG-EIBRCODE-2  PIC X(8) VALUE SPACES.         
        10 FILLER                PIC X(12) VALUE ' PARAGRAPH: '.  
        10 ERROR-DEBUG-LOCATION  PIC X(15) VALUE SPACES.          
        10 FILLER                PIC X(9)  VALUE SPACES.          
     05 WS-ERR-DISPLAY2.                                          
       10  FILLER                  PIC  X(13) VALUE               
       '  MQ   ERROR:'.                                           
       10  FILLER                  PIC  X(9) VALUE                
       '  LEVEL ='.                                               
       10  WS-LEVEL                PIC  X(8) VALUE SPACES.        
       10  FILLER                  PIC  X(9) VALUE                
       ', FUNC  ='.                                               
       10  WS-FUNCTION             PIC  X(8) VALUE SPACES.        
       10  FILLER                  PIC  X(9) VALUE                
       ', CC    ='.                                               
       10  WS-ERR-DISPLAY-CCODE    PIC  9(4) VALUE ZERO.          
       10  FILLER                  PIC  X(9) VALUE                
       ', RC    ='.                                               
       10  WS-ERR-DISPLAY-RCODE    PIC  9(4) VALUE ZERO.          
       10  FILLER                  PIC  X(4) VALUE '****'.        
     05 WS-ERR-DISPLAY3.                                          
        10 FILLER                PIC X(9) VALUE 'EIBRESP: '.      
        10 ERROR-DEBUG-EIBRESP   PIC 9(8) VALUE ZEROS.            
        10 FILLER                PIC X(14) VALUE '   EIBRESP2: '. 
        10 ERROR-DEBUG-EIBRESP2  PIC 9(8) VALUE ZEROS.            
        10 FILLER                PIC X(4) VALUE SPACES.           
        10 FILLER                PIC X(12) VALUE ' EIBRSRCE: '.   
        10 ERROR-DEBUG-EIBRSRCE  PIC X(8) VALUE SPACES.           
        10 FILLER                PIC X(10) VALUE '  ABCODE: '.    
        10 ERROR-DEBUG-ABEND     PIC X(4) VALUE SPACES.           
        10 FILLER                PIC X(2) VALUE '**'.             
*----------------------------------------------------------------*
* ERROR VALUES                                                    
*----------------------------------------------------------------*
 01  WS-ERR.                                                      
     02 ERR-HANDLER-COMMAREA.                                     
        05 ERR-CURRENT-INFO.                                      
          10 ERR-COM-HANDLER       PIC  X(48) VALUE SPACES.       
          10 ERR-QUEUE             PIC  X(48) VALUE SPACES.       
          10 ERR-FILE              PIC  X(8)  VALUE SPACES.       
          10 ERR-DETAIL            PIC  X(80) VALUE SPACES.       
          10 ERR-DETAIL2           PIC  X(80) VALUE SPACES.       
          10 ERR-Q-CODE            PIC S9(8) COMP VALUE ZERO.     
          10 FILLER                PIC  X(8) VALUE SPACES.        
                                                                  
        05 ERR-RESULTS.                                           
          10 ERR-CODE              PIC  9(6) VALUE ZERO.          
          10 FILLER                PIC  XX   VALUE SPACES.        
          10 ERR-PROGRAM           PIC  X(8) VALUE SPACES.        
          10 ERR-TRANID            PIC  X(4) VALUE SPACES.        
          10 ERR-TERMID            PIC  X(4) VALUE SPACES.        
          10 ERR-TASKNO            PIC S9(7)  COMP-3 VALUE ZERO.  
          10 ERR-ABSTIME           PIC S9(15) COMP-3 VALUE ZERO.  
                                                                  
          10 ERR-DEBUG-EIBFN       PIC  XX   VALUE SPACES.        
          10 ERR-DEBUG-EIBRCODE    PIC  X(6) VALUE LOW-VALUES.    
          10 ERR-DEBUG-EIBRSRCE    PIC  X(8) VALUE LOW-VALUES.    
          10 ERR-DEBUG-EIBRESP     PIC S9(8) COMP VALUE ZEROS.    
          10 ERR-DEBUG-EIBRESP2    PIC S9(8) COMP VALUE ZEROS.    
          10 ERR-DEBUG-EIBERRCD    PIC  X(4) VALUE LOW-VALUES.    
          10 ERR-DEBUG-ABEND       PIC  X(4) VALUE SPACES.        
          10 FILLER                PIC  X(12) VALUE SPACES.       
                                                                  
*---------------------------------------------------------------* 
 01  MSG-ERROR-MESSAGES.                                          
     05 ERR-NO-ENVIRONMENT           PIC  9(6) VALUE 900000.      
                                                                  
     05 ERR-CICS-ERROR               PIC  9(6) VALUE 800000.      
     05 ERR-CICS-INVALID-REQ         PIC  9(6) VALUE 800010.      
     05 ERR-CICS-ILLOGIC             PIC  9(6) VALUE 800011.      
     05 ERR-CICS-ERROR-CHECKPOINT    PIC  9(6) VALUE 800090.      
     05 ERR-CICS-ABEND               PIC  9(6) VALUE 800099.      
     05 ERR-CICS-FILE-NOTOPEN        PIC  9(6) VALUE 801012.      
     05 ERR-CICS-DISABLE             PIC  9(6) VALUE 801019.      
     05 ERR-CICS-NO-STORAGE          PIC  9(6) VALUE 802000.      
     05 ERR-CICS-LENGTH-ERR          PIC  9(6) VALUE 803001.      
     05 ERR-CICS-MAPFAIL             PIC  9(6) VALUE 808000.      
     05 ERR-CICS-PGMIDERR            PIC  9(6) VALUE 809000.      
     05 ERR-CICS-FILEID              PIC  9(6) VALUE 809010.      
     05 ERR-CICS-NOFILE              PIC  9(6) VALUE 809011.      
     05 ERR-CICS-IO-ERROR            PIC  9(6) VALUE 809012.      
     05 ERR-CICS-TRANIDERR           PIC  9(6) VALUE 809050.      
                                                                  
     05 ERR-COM-FREE-ERROR           PIC  9(6) VALUE 501001.      
     05 ERR-COM-EIB-ERROR            PIC  9(6) VALUE 501002.      
     05 ERR-COM-STAT-ERROR           PIC  9(6) VALUE 501003.      
     05 ERR-COM-ALLOC-ERROR          PIC  9(6) VALUE 501004.      
     05 ERR-COM-ALLOC-RETRY          PIC  9(6) VALUE 501005.      
     05 ERR-COM-CONN-ERROR           PIC  9(6) VALUE 501006.      
     05 ERR-COM-SEND-ERROR           PIC  9(6) VALUE 501008.      
     05 ERR-COM-RECV-RESP-ERR        PIC  9(6) VALUE 501009.      
     05 ERR-COM-RESP-TYPE            PIC  9(6) VALUE 501010.      
     05 ERR-COM-RESP-MSN             PIC  9(6) VALUE 501011.      
     05 ERR-COM-RESP-FATAL           PIC  9(6) VALUE 501012.      
     05 ERR-COM-MSG-ERROR            PIC  9(6) VALUE 501013.      
     05 ERR-COM-BIG-INDIAN           PIC  9(6) VALUE 501014.      
     05 ERR-COM-TSH-ERROR            PIC  9(6) VALUE 501015.      
     05 ERR-COM-CCSID-ERROR          PIC  9(6) VALUE 501016.      
     05 ERR-COM-MSH-ERROR            PIC  9(6) VALUE 501017.      
     05 ERR-COM-MQX-ERROR            PIC  9(6) VALUE 501018.      
     05 ERR-COM-INIT-ERROR           PIC  9(6) VALUE 501019.      
     05 ERR-COM-FAP-ERROR            PIC  9(6) VALUE 501020.      
     05 ERR-COM-MSG-SIZE             PIC  9(6) VALUE 501021.      
     05 ERR-COM-WRAP-ERROR           PIC  9(6) VALUE 501022.      
     05 ERR-COM-MCP-DOWN             PIC  9(6) VALUE 501023.      
     05 ERR-COM-DOWN                 PIC  9(6) VALUE 501024.      
     05 ERR-COM-NOT-FOUND            PIC  9(6) VALUE 501025.      
     05 ERR-COM-ERROR                PIC  9(6) VALUE 501026.      
     05 ERR-COM-BUSY                 PIC  9(6) VALUE 501027.      
     05 ERR-COM-RESYNC-ERROR         PIC  9(6) VALUE 501028.      
     05 ERR-COM-STATUS-ERROR         PIC  9(6) VALUE 501029.      
     05 ERR-COM-LENGTH-ERROR         PIC  9(6) VALUE 501030.      
     05 ERR-COM-MSG-PER-BATCH        PIC  9(6) VALUE 501031.      
     05 ERR-COM-MAX-TRANSM-SIZE      PIC  9(6) VALUE 501032.      
     05 ERR-COM-RESET-MSN            PIC  9(6) VALUE 501050.      
                                                                  
     05 ERR-INT-LINK-ERROR           PIC  9(6) VALUE 400000.      
     05 ERR-INT-LINK-COM-SIZE        PIC  9(6) VALUE 400001.      
     05 ERR-INT-LINK-COM-DATA        PIC  9(6) VALUE 400002.      
     05 ERR-INT-RETURN-ERROR         PIC  9(6) VALUE 400003.      
     05 ERR-INT-MOVE-ERROR           PIC  9(6) VALUE 400010.      
     05 ERR-INT-STRUC-MISSING        PIC  9(6) VALUE 402000.      
     05 ERR-INT-STRUC-ERROR          PIC  9(6) VALUE 402090.      
                                                                  
     05 ERR-LOGIC-NOT-SUPPORTED      PIC  9(6) VALUE 300000.      
     05 ERR-LOGIC-STARTED-WRONG      PIC  9(6) VALUE 300010.      
     05 ERR-LOGIC-REPEATED-FAILURE   PIC  9(6) VALUE 300020.      
     05 ERR-LOGIC-LOCKS-EXCEEDED     PIC  9(6) VALUE 300030.      
     05 ERR-LOGIC-MISSING-RECORD     PIC  9(6) VALUE 301000.      
     05 ERR-LOGIC-RECORD-DUPLICATED  PIC  9(6) VALUE 301010.      
     05 ERR-LOGIC-Q-CKP-MISSING      PIC  9(6) VALUE 309010.      
                                                                  
     05 ERR-PROC-SYSTEM-STOPPED      PIC  9(6) VALUE 100000.      
     05 ERR-PROC-SYSTEM-ACTIVE       PIC  9(6) VALUE 100010.      
     05 ERR-PROC-SYS-START-NOQDR     PIC  9(6) VALUE 100011.      
     05 ERR-PROC-SYS-START-MAXQDR    PIC  9(6) VALUE 100012.      
     05 ERR-PROC-SYS-START-MAXCOM    PIC  9(6) VALUE 100013.      
     05 ERR-PROC-SYS-START-NOSYS     PIC  9(6) VALUE 100090.      
     05 ERR-PROC-Q-EXCEEDED-DEPTH    PIC  9(6) VALUE 101000.      
     05 ERR-PROC-Q-CONCURRENT-UPD    PIC  9(6) VALUE 101010.      
     05 ERR-PROC-Q-NOTFOUND          PIC  9(6) VALUE 101015.      
     05 ERR-PROC-Q-STOPPED           PIC  9(6) VALUE 101090.      
     05 ERR-PROC-Q-DISABLED          PIC  9(6) VALUE 101091.      
     05 ERR-PROC-QSN-LIMIT-REACHED   PIC  9(6) VALUE 102090.      
     05 ERR-PROC-FILE-SPACE-PUT      PIC  9(6) VALUE 102091.      
     05 ERR-PROC-FILE-SPACE          PIC  9(6) VALUE 102092.      
     05 ERR-PROC-DUAL-Q-ERROR        PIC  9(6) VALUE 104021.      
     05 ERR-PROC-DUAL-Q-FILE         PIC  9(6) VALUE 104022.      
     05 ERR-PROC-DUAL-Q-LOGIC        PIC  9(6) VALUE 104023.      
     05 ERR-PROC-TRIGGER-ERROR       PIC  9(6) VALUE 105090.      
     05 ERR-PROC-TRIGGER-DATA        PIC  9(6) VALUE 105091.      
     05 ERR-PROC-NOT-AUTHORIZED      PIC  9(6) VALUE 109000.      
                                                                  
     05 ERR-WARN-SYS-STARTED-W-ERR   PIC  9(6) VALUE 010000.      
     05 ERR-WARN-SYS-STARTED-W-FILER PIC  9(6) VALUE 010001.      
     05 ERR-WARN-SYS-STARTED-W-COMER PIC  9(6) VALUE 010002.      
     05 ERR-WARN-SYS-STARTED-W-CHANG PIC  9(6) VALUE 010003.      
                                                                  
     05 ERR-WARN-COM-CONNECT         PIC  9(6) VALUE 005000.      
     05 ERR-WARN-COM-OPENED          PIC  9(6) VALUE 005001.      
     05 ERR-WARN-COM-QUEUE-OPENED    PIC  9(6) VALUE 005002.      
     05 ERR-WARN-COM-LU62-CONNECT    PIC  9(6) VALUE 005003.      
     05 ERR-WARN-COM-RECEIVER-ALLOC  PIC  9(6) VALUE 005004.      
     05 ERR-WARN-COM-QUEUE-EMPTY     PIC  9(6) VALUE 005005.      
     05 ERR-WARN-COM-QUEUE-CLOSED    PIC  9(6) VALUE 005006.      
     05 ERR-WARN-COM-DISC            PIC  9(6) VALUE 005007.      
     05 ERR-WARN-COM-SHUT            PIC  9(6) VALUE 005008.      
     05 ERR-WARN-COM-SHUT-SENT       PIC  9(6) VALUE 005009.      
                                                                  
     05 ERR-FUNCTION-STARTED         PIC  9(6) VALUE 000100.      
     05 ERR-FUNCTION-DONE            PIC  9(6) VALUE 001000.      
     05 ERR-FUNCTION-NOT-DONE        PIC  9(6) VALUE 001090.      
                                                                  
     05 ERR-WARN-SYS-STARTED         PIC  9(6) VALUE 000000.      
                                                                  
     05  SYNCH-MSN-ERROR              PIC 9(6)    VALUE 3.        
     05  SYNCH-MSG-DUP                PIC 9(6)    VALUE 4.        
     05  LU62-FREE-ERROR              PIC 9(6)    VALUE 10.       
     05  LU62-EIB-ERROR               PIC 9(6)    VALUE 11.       
     05  LU62-STAT-ERROR              PIC 9(6)    VALUE 12.       
     05  LU62-ALLOC-ERROR             PIC 9(6)    VALUE 13.       
     05  LU62-ALLOC-RETRY-ERROR       PIC 9(6)    VALUE 14.       
     05  LU62-CONN-ERROR              PIC 9(6)    VALUE 15.       
     05  LU62-SEND-ERROR              PIC 9(6)    VALUE 16.       
     05  LU62-RECV-RESP-ERROR         PIC 9(6)    VALUE 17.       
     05  INVLD-RESP-TYPE              PIC 9(6)    VALUE 23.       
     05  INVLD-RESP-MSN               PIC 9(6)    VALUE 24.       
     05  FATAL-RESP-TYPE              PIC 9(6)    VALUE 25.       
     05  RECOVERABLE-RESP-TYPE        PIC 9(6)    VALUE 26.       
     05  PARSER-MSN-ERROR             PIC 9(6)    VALUE 29.       
     05  PARSER-TYPE-ERROR            PIC 9(6)    VALUE 30.       
     05  PARSER-PDM-ERROR             PIC 9(6)    VALUE 31.       
     05  PARSER-SID-ERROR             PIC 9(6)    VALUE 32.       
     05  PARSER-PN-ERROR              PIC 9(6)    VALUE 33.       
     05  PARSER-KEY-ERROR             PIC 9(6)    VALUE 34.       
     05  PARSER-APID-ERROR            PIC 9(6)    VALUE 35.       
     05  PARSER-ORG-DT-ERROR          PIC 9(6)    VALUE 38.       
     05  PARSER-ORIG-MSN-ERROR        PIC 9(6)    VALUE 39.       
     05  PARSER-BODY-ERROR            PIC 9(6)    VALUE 40.       
     05  PARSER-STATUS-ERROR          PIC 9(6)    VALUE 41.       
     05  PARSER-LENGTH-ERROR          PIC 9(6)    VALUE 42.       
     05  MCCONN-ERROR                 PIC 9(6)    VALUE 51.       
     05  MQOPEN-ERROR                 PIC 9(6)    VALUE 52.       
     05  MQGET-ERROR                  PIC 9(6)    VALUE 53.       
     05  MQPUT-ERROR                  PIC 9(6)    VALUE 54.       
     05  MQPT1-ERROR                  PIC 9(6)    VALUE 55.       
     05  MQCLOSE-ERROR                PIC 9(6)    VALUE 56.       
     05  MQDISC-ERROR                 PIC 9(6)    VALUE 57.       
     05  QM-OTHER-ERROR               PIC 9(6)    VALUE 60.       
     05  RECV-RETURN-LON-STATUS       PIC 9(6)    VALUE 80.       
     05  RECV-RETURN-LON-TYPE         PIC 9(6)    VALUE 81.       
     05  SIDRC-RETURN-MLP-FORMAT      PIC 9(6)    VALUE 91.       
                                                                  
*---------------------------------------------------------------* 
*---------------------------------------------------------------* 
 01  FILLER.                                                      
*    COPY CMQV.                                                   
*/INCLUDE CMQV                                                    
*/INCLUDE  COPYR                                                  
******************************************************************
**                                                              **
**  FILE NAME:        CMQV                                      **
**                                                              **
**  DESCRIPTIVE NAME: COBOL copy file for MQI constants         **
**                                                              **
**  VERSION 1.4.0                                               **
**                                                              **
**  FUNCTION:         This file declares the constants          **
**                    which form part of the IBM Message        **
**                    Queue Interface (MQI).                    **
**                                                              **
******************************************************************
                                                                  
******************************************************************
**  Values Related to MQDLH Structure                           **
******************************************************************
**   Structure Identifier                                         
  10 MQDLH-STRUC-ID PIC X(4) VALUE 'DLH '.                        
                                                                  
**   Structure Version Number                                     
  10 MQDLH-VERSION-1 PIC S9(9) BINARY  VALUE 1.                   
                                                                  
                                                                  
******************************************************************
**  Values Related to MQGMO Structure                           **
******************************************************************
                                                                  
**   Structure Identifier                                         
  10 MQGMO-STRUC-ID PIC X(4) VALUE 'GMO '.                        
                                                                  
**   Structure Version Number                                     
  10 MQGMO-VERSION-1 PIC S9(9) BINARY  VALUE 1.                   
                                                                  
**   Get-Message Options                                          
  10 MQGMO-WAIT                     PIC S9(9) BINARY  VALUE 1.    
  10 MQGMO-NO-WAIT                  PIC S9(9) BINARY  VALUE 0.    
  10 MQGMO-BROWSE-FIRST             PIC S9(9) BINARY  VALUE 16.   
  10 MQGMO-BROWSE-NEXT              PIC S9(9) BINARY  VALUE 32.   
  10 MQGMO-ACCEPT-TRUNCATED-MSG     PIC S9(9) BINARY  VALUE 64.   
  10 MQGMO-SET-SIGNAL               PIC S9(9) BINARY  VALUE 8.    
  10 MQGMO-SYNCPOINT                PIC S9(9) BINARY  VALUE 2.    
  10 MQGMO-NO-SYNCPOINT             PIC S9(9) BINARY  VALUE 4.    
  10 MQGMO-MSG-UNDER-CURSOR         PIC S9(9) BINARY  VALUE 256.  
  10 MQGMO-LOCK                     PIC S9(9) BINARY  VALUE 512.  
  10 MQGMO-UNLOCK                   PIC S9(9) BINARY  VALUE 1024. 
                                                                  
**   Wait Interval                                                
  10 MQWI-UNLIMITED PIC S9(9) BINARY  VALUE -1.                   
                                                                  
                                                                  
******************************************************************
**  Values Related to MQMD Structure                            **
******************************************************************
                                                                  
**   Structure Identifier                                         
  10 MQMD-STRUC-ID PIC X(4) VALUE 'MD  '.                         
                                                                  
**   Structure Version Number                                     
  10 MQMD-VERSION-1 PIC S9(9) BINARY  VALUE 1.                    
                                                                  
**   Report Options                                               
  10 MQRO-NONE PIC S9(9) BINARY  VALUE 0.                         
                                                                  
**   Message Types                                                
  10 MQMT-REQUEST  PIC S9(9) BINARY  VALUE 1.                     
  10 MQMT-REPLY    PIC S9(9) BINARY  VALUE 2.                     
  10 MQMT-DATAGRAM PIC S9(9) BINARY  VALUE 8.                     
  10 MQMT-REPORT   PIC S9(9) BINARY  VALUE 4.                     
                                                                  
**   Expiry Value                                                 
  10 MQEI-UNLIMITED PIC S9(9) BINARY  VALUE -1.                   
                                                                  
**   Feedback Values                                              
  10 MQFB-NONE         PIC S9(9) BINARY  VALUE 0.                 
  10 MQFB-QUIT         PIC S9(9) BINARY  VALUE 256.               
  10 MQFB-SYSTEM-FIRST PIC S9(9) BINARY  VALUE 1.                 
  10 MQFB-SYSTEM-LAST  PIC S9(9) BINARY  VALUE 65535.             
  10 MQFB-APPL-FIRST   PIC S9(9) BINARY  VALUE 65536.             
  10 MQFB-APPL-LAST    PIC S9(9) BINARY  VALUE 999999999.         
                                                                  
* format                                                          
  10 MQFMT-NONE                  PIC  X(8) VALUE SPACES.          
  10 MQFMT-DEAD-LETTER-Q-HEADER  PIC  X(8) VALUE 'MQDLQH'.        
  10 MQFMT-TRIGGER               PIC  X(8) VALUE 'MQTRIG'.        
  10 MQFMT-XMIT-Q-HEADER         PIC  X(8) VALUE 'MQXMIT'.        
                                                                  
**   Encoding Value                                               
  10 MQENC-NATIVE PIC S9(9) BINARY  VALUE 785.                    
                                                                  
**   Encoding Masks                                               
  10 MQENC-INTEGER-MASK  PIC S9(9) BINARY  VALUE 15.              
  10 MQENC-DECIMAL-MASK  PIC S9(9) BINARY  VALUE 240.             
  10 MQENC-FLOAT-MASK    PIC S9(9) BINARY  VALUE 3840.            
  10 MQENC-RESERVED-MASK PIC S9(9) BINARY  VALUE -4096.           
                                                                  
**   Encodings for Binary Integers                                
  10 MQENC-INTEGER-UNDEFINED PIC S9(9) BINARY  VALUE 0.           
  10 MQENC-INTEGER-NORMAL    PIC S9(9) BINARY  VALUE 1.           
  10 MQENC-INTEGER-REVERSED  PIC S9(9) BINARY  VALUE 2.           
                                                                  
**   Encodings for Packed-Decimal Integers                        
  10 MQENC-DECIMAL-UNDEFINED PIC S9(9) BINARY  VALUE 0.           
  10 MQENC-DECIMAL-NORMAL    PIC S9(9) BINARY  VALUE 16.          
  10 MQENC-DECIMAL-REVERSED  PIC S9(9) BINARY  VALUE 32.          
                                                                  
**   Encodings for Floating-Point Numbers                         
  10 MQENC-FLOAT-UNDEFINED     PIC S9(9) BINARY  VALUE 0.         
  10 MQENC-FLOAT-IEEE-NORMAL   PIC S9(9) BINARY  VALUE 256.       
  10 MQENC-FLOAT-IEEE-REVERSED PIC S9(9) BINARY  VALUE 512.       
  10 MQENC-FLOAT-S390          PIC S9(9) BINARY  VALUE 768.       
                                                                  
**   Coded Character-Set Identifier                               
  10 MQCCSI-Q-MGR PIC S9(9) BINARY  VALUE 0.                      
                                                                  
**   Persistence Values                                           
  10 MQPER-PERSISTENT           PIC S9(9) BINARY  VALUE 1.        
  10 MQPER-PERSISTENCE-AS-Q-DEF PIC S9(9) BINARY  VALUE 2.        
                                                                  
**   Message Id Value                                             
  10 MQMI-NONE PIC X(24) VALUE LOW-VALUES.                        
                                                                  
**   Correllation Id Value                                        
  10 MQCI-NONE PIC X(24) VALUE LOW-VALUES.                        
                                                                  
                                                                  
******************************************************************
**  Values Related to MQOD Structure                            **
******************************************************************
                                                                  
**   Structure Identifier                                         
  10 MQOD-STRUC-ID PIC X(4) VALUE 'OD  '.                         
                                                                  
**   Structure Version Number                                     
  10 MQOD-VERSION-1 PIC S9(9) BINARY  VALUE 1.                    
                                                                  
**   Object Types                                                 
  10 MQOT-Q PIC S9(9) BINARY  VALUE 1.                            
                                                                  
                                                                  
******************************************************************
**  Values Related to MQPMO Structure                           **
******************************************************************
                                                                  
**   Structure Identifier                                         
  10 MQPMO-STRUC-ID PIC X(4) VALUE 'PMO '.                        
                                                                  
**   Structure Version Number                                     
  10 MQPMO-VERSION-1 PIC S9(9) BINARY  VALUE 1.                   
                                                                  
**   Put-Message Options                                          
  10 MQPMO-SYNCPOINT            PIC S9(9) BINARY  VALUE 2.        
  10 MQPMO-NO-SYNCPOINT         PIC S9(9) BINARY  VALUE 4.        
                                                                  
******************************************************************
**  Values Related to MQTM Structure                            **
******************************************************************
                                                                  
**   Structure Identifier                                         
  10 MQTM-STRUC-ID PIC X(4) VALUE 'TM  '.                         
                                                                  
**   Structure Version Number                                     
  10 MQTM-VERSION-1 PIC S9(9) BINARY  VALUE 1.                    
                                                                  
                                                                  
******************************************************************
**  Values Related to MQCLOSE Call                              **
******************************************************************
                                                                  
**   Close Options                                                
  10 MQCO-NONE PIC S9(9) BINARY  VALUE 0.                         
                                                                  
                                                                  
******************************************************************
**  Values Related to MQINQ Call                                **
******************************************************************
                                                                  
**   Character-Attribute Selectors                                
  10 MQCA-BASE-Q-NAME       PIC S9(9) BINARY  VALUE 2002.         
  10 MQCA-CREATION-DATE     PIC S9(9) BINARY  VALUE 2004.         
  10 MQCA-CREATION-TIME     PIC S9(9) BINARY  VALUE 2005.         
  10 MQCA-FIRST             PIC S9(9) BINARY  VALUE 2001.         
  10 MQCA-INITIATION-Q-NAME PIC S9(9) BINARY  VALUE 2008.         
  10 MQCA-LAST              PIC S9(9) BINARY  VALUE 4000.         
  10 MQCA-PROCESS-NAME      PIC S9(9) BINARY  VALUE 2012.         
  10 MQCA-Q-DESC            PIC S9(9) BINARY  VALUE 2013.         
  10 MQCA-Q-NAME            PIC S9(9) BINARY  VALUE 2016.         
  10 MQCA-REMOTE-Q-MGR-NAME PIC S9(9) BINARY  VALUE 2017.         
  10 MQCA-REMOTE-Q-NAME     PIC S9(9) BINARY  VALUE 2018.         
                                                                  
**   Integer-Attribute Selectors                                  
  10 MQIA-CURRENT-Q-DEPTH   PIC S9(9) BINARY  VALUE 3.            
  10 MQIA-DEF-PERSISTENCE   PIC S9(9) BINARY  VALUE 5.            
  10 MQIA-DEFINITION-TYPE   PIC S9(9) BINARY  VALUE 7.            
  10 MQIA-FIRST             PIC S9(9) BINARY  VALUE 1.            
  10 MQIA-INHIBIT-GET       PIC S9(9) BINARY  VALUE 9.            
  10 MQIA-INHIBIT-PUT       PIC S9(9) BINARY  VALUE 10.           
  10 MQIA-LAST              PIC S9(9) BINARY  VALUE 2000.         
  10 MQIA-MAX-MSG-LENGTH    PIC S9(9) BINARY  VALUE 13.           
  10 MQIA-MAX-Q-DEPTH       PIC S9(9) BINARY  VALUE 15.           
  10 MQIA-OPEN-INPUT-COUNT  PIC S9(9) BINARY  VALUE 17.           
  10 MQIA-OPEN-OUTPUT-COUNT PIC S9(9) BINARY  VALUE 18.           
  10 MQIA-Q-TYPE            PIC S9(9) BINARY  VALUE 20.           
  10 MQIA-SHAREABILITY      PIC S9(9) BINARY  VALUE 23.           
  10 MQIA-TRIGGER-CONTROL   PIC S9(9) BINARY  VALUE 24.           
  10 MQIA-TRIGGER-TYPE      PIC S9(9) BINARY  VALUE 28.           
  10 MQIA-USAGE             PIC S9(9) BINARY  VALUE 12.           
                                                                  
**   Integer Attribute Value Denoting 'Not Applicable'            
  10 MQIAV-NOT-APPLICABLE PIC S9(9) BINARY  VALUE -1.             
                                                                  
                                                                  
******************************************************************
**  Values Related to MQOPEN Call                               **
******************************************************************
                                                                  
**   Open Options                                                 
  10 MQOO-INPUT-SHARED    PIC S9(9) BINARY  VALUE 2.              
  10 MQOO-INPUT-EXCLUSIVE PIC S9(9) BINARY  VALUE 4.              
  10 MQOO-BROWSE          PIC S9(9) BINARY  VALUE 8.              
  10 MQOO-OUTPUT          PIC S9(9) BINARY  VALUE 16.             
  10 MQOO-INQUIRE         PIC S9(9) BINARY  VALUE 32.             
                                                                  
                                                                  
******************************************************************
**  Values Related to All Calls                                 **
******************************************************************
                                                                  
**   String Lengths                                               
  10 MQ-CREATION-DATE-LENGTH     PIC S9(9) BINARY  VALUE 12.      
  10 MQ-CREATION-TIME-LENGTH     PIC S9(9) BINARY  VALUE 8.       
  10 MQ-PROCESS-APPL-ID-LENGTH   PIC S9(9) BINARY  VALUE 256.     
  10 MQ-PROCESS-DESC-LENGTH      PIC S9(9) BINARY  VALUE 64.      
  10 MQ-PROCESS-ENV-DATA-LENGTH  PIC S9(9) BINARY  VALUE 128.     
  10 MQ-PROCESS-NAME-LENGTH      PIC S9(9) BINARY  VALUE 48.      
  10 MQ-PROCESS-USER-DATA-LENGTH PIC S9(9) BINARY  VALUE 128.     
  10 MQ-Q-DESC-LENGTH            PIC S9(9) BINARY  VALUE 64.      
  10 MQ-Q-NAME-LENGTH            PIC S9(9) BINARY  VALUE 48.      
  10 MQ-Q-MGR-DESC-LENGTH        PIC S9(9) BINARY  VALUE 64.      
  10 MQ-Q-MGR-NAME-LENGTH        PIC S9(9) BINARY  VALUE 48.      
  10 MQ-TRIGGER-DATA-LENGTH      PIC S9(9) BINARY  VALUE 64.      
                                                                  
**   Completion Codes                                             
  10 MQCC-OK      PIC S9(9) BINARY  VALUE 0.                      
  10 MQCC-WARNING PIC S9(9) BINARY  VALUE 1.                      
  10 MQCC-FAILED  PIC S9(9) BINARY  VALUE 2.                      
                                                                  
**   Reason Codes                                                 
  10 MQRC-NONE                      PIC S9(9) BINARY  VALUE 0.    
  10 MQRC-ACCESS-RESTRICTED         PIC S9(9) BINARY  VALUE 2000. 
  10 MQRC-ALIAS-BASE-Q-TYPE-ERROR   PIC S9(9) BINARY  VALUE 2001. 
  10 MQRC-ALREADY-CONNECTED         PIC S9(9) BINARY  VALUE 2002. 
  10 MQRC-BUFFER-ERROR              PIC S9(9) BINARY  VALUE 2004. 
  10 MQRC-BUFFER-LENGTH-ERROR       PIC S9(9) BINARY  VALUE 2005. 
  10 MQRC-CHAR-ATTR-LENGTH-ERROR    PIC S9(9) BINARY  VALUE 2006. 
  10 MQRC-CHAR-ATTRS-ERROR          PIC S9(9) BINARY  VALUE 2007. 
  10 MQRC-CHAR-ATTRS-TOO-SHORT      PIC S9(9) BINARY  VALUE 2008. 
  10 MQRC-CONNECTION-BROKEN         PIC S9(9) BINARY  VALUE 2009. 
  10 MQRC-DATA-LENGTH-ERROR         PIC S9(9) BINARY  VALUE 2010. 
  10 MQRC-EXPIRY-ERROR              PIC S9(9) BINARY  VALUE 2013. 
  10 MQRC-FEEDBACK-ERROR            PIC S9(9) BINARY  VALUE 2014. 
  10 MQRC-GET-INHIBITED             PIC S9(9) BINARY  VALUE 2016. 
  10 MQRC-HANDLE-NOT-AVAILABLE      PIC S9(9) BINARY  VALUE 2017. 
  10 MQRC-HCONN-ERROR               PIC S9(9) BINARY  VALUE 2018. 
  10 MQRC-HOBJ-ERROR                PIC S9(9) BINARY  VALUE 2019. 
  10 MQRC-INT-ATTR-COUNT-ERROR      PIC S9(9) BINARY  VALUE 2021. 
  10 MQRC-INT-ATTR-COUNT-TOO-SMALL  PIC S9(9) BINARY  VALUE 2022. 
  10 MQRC-INT-ATTRS-ARRAY-ERROR     PIC S9(9) BINARY  VALUE 2023. 
  10 MQRC-MAX-CONNS-LIMIT-REACHED   PIC S9(9) BINARY  VALUE 2025. 
  10 MQRC-MD-ERROR                  PIC S9(9) BINARY  VALUE 2026. 
  10 MQRC-MISSING-REPLY-TO-Q        PIC S9(9) BINARY  VALUE 2027. 
  10 MQRC-MSG-TYPE-ERROR            PIC S9(9) BINARY  VALUE 2029. 
  10 MQRC-MSG-TOO-BIG-FOR-Q         PIC S9(9) BINARY  VALUE 2030. 
  10 MQRC-NO-MSG-AVAILABLE          PIC S9(9) BINARY  VALUE 2033. 
  10 MQRC-NO-MSG-UNDER-CURSOR       PIC S9(9) BINARY  VALUE 2034. 
  10 MQRC-NOT-AUTHORIZED            PIC S9(9) BINARY  VALUE 2035. 
  10 MQRC-NOT-OPEN-FOR-BROWSE       PIC S9(9) BINARY  VALUE 2036. 
  10 MQRC-NOT-OPEN-FOR-INPUT        PIC S9(9) BINARY  VALUE 2037. 
  10 MQRC-NOT-OPEN-FOR-INQUIRE      PIC S9(9) BINARY  VALUE 2038. 
  10 MQRC-NOT-OPEN-FOR-OUTPUT       PIC S9(9) BINARY  VALUE 2039. 
  10 MQRC-OBJECT-CHANGED            PIC S9(9) BINARY  VALUE 2041. 
  10 MQRC-OBJECT-IN-USE             PIC S9(9) BINARY  VALUE 2042. 
  10 MQRC-OBJECT-TYPE-ERROR         PIC S9(9) BINARY  VALUE 2043. 
  10 MQRC-OD-ERROR                  PIC S9(9) BINARY  VALUE 2044. 
  10 MQRC-OPTION-NOT-VALID-FOR-TYPE PIC S9(9) BINARY  VALUE 2045. 
  10 MQRC-OPTIONS-ERROR             PIC S9(9) BINARY  VALUE 2046. 
  10 MQRC-PERSISTENCE-ERROR         PIC S9(9) BINARY  VALUE 2047. 
  10 MQRC-PRIORITY-EXCEEDS-MAXIMUM  PIC S9(9) BINARY  VALUE 2049. 
  10 MQRC-PRIORITY-ERROR            PIC S9(9) BINARY  VALUE 2050. 
  10 MQRC-PUT-INHIBITED             PIC S9(9) BINARY  VALUE 2051. 
  10 MQRC-Q-FULL                    PIC S9(9) BINARY  VALUE 2053. 
  10 MQRC-Q-SPACE-NOT-AVAILABLE     PIC S9(9) BINARY  VALUE 2056. 
  10 MQRC-Q-MGR-NAME-ERROR          PIC S9(9) BINARY  VALUE 2058. 
  10 MQRC-Q-MGR-NOT-AVAILABLE       PIC S9(9) BINARY  VALUE 2059. 
  10 MQRC-REPORT-OPTIONS-ERROR      PIC S9(9) BINARY  VALUE 2061. 
  10 MQRC-SECURITY-ERROR            PIC S9(9) BINARY  VALUE 2063. 
  10 MQRC-SELECTOR-COUNT-ERROR      PIC S9(9) BINARY  VALUE 2065. 
  10 MQRC-SELECTOR-LIMIT-EXCEEDED   PIC S9(9) BINARY  VALUE 2066. 
  10 MQRC-SELECTOR-ERROR            PIC S9(9) BINARY  VALUE 2067. 
  10 MQRC-SELECTOR-NOT-FOR-TYPE     PIC S9(9) BINARY  VALUE 2068. 
  10 MQRC-SIGNAL-OUTSTANDING        PIC S9(9) BINARY  VALUE 2069. 
  10 MQRC-SIGNAL-REQUEST-ACCEPTED   PIC S9(9) BINARY  VALUE 2070. 
  10 MQRC-STORAGE-NOT-AVAILABLE     PIC S9(9) BINARY  VALUE 2071. 
  10 MQRC-SYNCPOINT-NOT-AVAILABLE   PIC S9(9) BINARY  VALUE 2072. 
  10 MQRC-TRUNCATED-MSG-ACCEPTED    PIC S9(9) BINARY  VALUE 2079. 
  10 MQRC-TRUNCATED-MSG-FAILED      PIC S9(9) BINARY  VALUE 2080. 
  10 MQRC-UNEXPECTED-CONNECT-ERROR  PIC S9(9) BINARY  VALUE 2081. 
  10 MQRC-UNKNOWN-ALIAS-BASE-Q      PIC S9(9) BINARY  VALUE 2082. 
  10 MQRC-UNKNOWN-OBJECT-NAME       PIC S9(9) BINARY  VALUE 2085. 
  10 MQRC-UNKNOWN-OBJECT-Q-MGR      PIC S9(9) BINARY  VALUE 2086. 
  10 MQRC-UNKNOWN-REMOTE-Q-MGR      PIC S9(9) BINARY  VALUE 2087. 
  10 MQRC-WAIT-INTERVAL-ERROR       PIC S9(9) BINARY  VALUE 2090. 
  10 MQRC-XMIT-Q-TYPE-ERROR         PIC S9(9) BINARY  VALUE 2091. 
  10 MQRC-XMIT-Q-USAGE-ERROR        PIC S9(9) BINARY  VALUE 2092. 
  10 MQRC-PMO-ERROR                 PIC S9(9) BINARY  VALUE 2173. 
  10 MQRC-GMO-ERROR                 PIC S9(9) BINARY  VALUE 2186. 
                                                                  
  10 MQRC-UNEXPECTED-ERROR          PIC S9(9) BINARY  VALUE 2195. 
  10 MQRC-MSG-ID-ERROR              PIC S9(9) BINARY  VALUE 2206. 
  10 MQRC-CORREL-ID-ERROR           PIC S9(9) BINARY  VALUE 2207. 
                                                                  
  10 MQRC-FILE-SYSTEM-ERROR         PIC S9(9) BINARY  VALUE 2208. 
  10 MQRC-NO-MSG-LOCKED             PIC S9(9) BINARY  VALUE 2209. 
                                                                  
                                                                  
******************************************************************
**  Values Related to Queue Attributes                          **
******************************************************************
                                                                  
**   Queue Types                                                  
  10 MQQT-LOCAL  PIC S9(9) BINARY  VALUE 1.                       
  10 MQQT-ALIAS  PIC S9(9) BINARY  VALUE 3.                       
  10 MQQT-REMOTE PIC S9(9) BINARY  VALUE 6.                       
                                                                  
**   Queue Definition Types                                       
  10 MQQDT-PREDEFINED PIC S9(9) BINARY  VALUE 1.                  
                                                                  
**   Inhibit Get                                                  
  10 MQQA-GET-INHIBITED PIC S9(9) BINARY  VALUE 1.                
  10 MQQA-GET-ALLOWED   PIC S9(9) BINARY  VALUE 0.                
                                                                  
**   Inhibit Put                                                  
  10 MQQA-PUT-INHIBITED PIC S9(9) BINARY  VALUE 1.                
  10 MQQA-PUT-ALLOWED   PIC S9(9) BINARY  VALUE 0.                
                                                                  
*---------------------------------------------------------------* 
*--CONNECT PARM                                                   
                                                                  
*--OPEN    PARM                                                   
 01  WS-Q-NAME-AREA.                                              
**   MQOD structure                                               
  10 MQOD.                                                        
**    Structure identifier                                        
   15 MQOD-STRUCID         PIC X(4) VALUE 'OD  '.                 
**    Structure version number                                    
   15 MQOD-VERSION         PIC S9(9) BINARY   VALUE 1.            
**    Object type                                                 
   15 MQOD-OBJECTTYPE      PIC S9(9) BINARY   VALUE 1.            
**    Object name                                                 
   15 MQOD-OBJECTNAME      PIC X(48) VALUE SPACES.                
**    Object queue manager name                                   
   15 MQOD-OBJECTQMGRNAME  PIC X(48) VALUE SPACES.                
**    Dynamic queue name                                          
   15 MQOD-DYNAMICQNAME    PIC X(48) VALUE '*'.                   
*    Alternate user identifier                                    
   15 MQOD-ALTERNATEUSERID PIC X(12) VALUE SPACES.                
                                                                  
 01  WS-Q-OPEN-OPTIONS.                                           
     05  WS-Q-OPEN-OPTIONS-VALUE    PIC S9(8) COMP.               
                                                                  
*--INQ                                                            
 01  MQI-CHAR-ATTR-LENGTH.                                        
     05  WS-CHAR-ATTR-LENGTH        PIC S9(8) COMP.               
 01  MQI-CHAR-ATTR.                                               
     05  WS-CHAR-ATTR            PIC X(500) VALUE SPACES.         
 01  WS-D-FILLER REDEFINES MQI-CHAR-ATTR.                         
     05  WS-A-DESC               PIC X(64).                       
     05  WS-A-Q-N                PIC X(64).                       
                                                                  
                                                                  
                                                                  
 01  WS-MSG-DESCRIPTOR.                                           
**   MQMD structure                                               
  10 MQMD.                                                        
**    Structure identifier                                        
   15 MQMD-STRUCID           PIC X(4) VALUE 'MD  '.               
**    Structure version number                                    
   15 MQMD-VERSION           PIC S9(9) BINARY  VALUE 1.           
**    Reserved                                                    
   15 MQMD-REPORT            PIC S9(9) BINARY  VALUE 0.           
**    Message type                                                
   15 MQMD-MSGTYPE           PIC S9(9) BINARY  VALUE 8.           
**    Reserved                                                    
   15 MQMD-EXPIRY            PIC S9(9) BINARY  VALUE -1.          
**    Feedback code                                               
   15 MQMD-FEEDBACK          PIC S9(9) BINARY  VALUE 0.           
**    Data encoding                                               
   15 MQMD-ENCODING          PIC S9(9) BINARY  VALUE 785.         
**    Coded character set identifier                              
   15 MQMD-CODEDCHARSETID    PIC S9(9) BINARY  VALUE 0.           
**    Format name                                                 
   15 MQMD-FORMAT            PIC X(8) VALUE SPACES.               
**    Reserved                                                    
   15 MQMD-PRIORITY          PIC S9(9) BINARY  VALUE 0.           
**    Message persistence                                         
   15 MQMD-PERSISTENCE       PIC S9(9) BINARY  VALUE 2.           
**    Message identifier                                          
   15 MQMD-MSGID             PIC X(24) VALUE LOW-VALUES.          
**    Correlation identifier                                      
   15 MQMD-CORRELID          PIC X(24) VALUE LOW-VALUES.          
**    Reserved                                                    
   15 MQMD-BACKOUTCOUNT      PIC S9(9) BINARY  VALUE 0.           
**    Name of reply queue                                         
   15 MQMD-REPLYTOQ          PIC X(48) VALUE SPACES.              
**    Name of reply queue manager                                 
   15 MQMD-REPLYTOQMGR       PIC X(48) VALUE SPACES.              
**    Reserved                                                    
   15 MQMD-USERIDENTIFIER    PIC X(12) VALUE SPACES.              
**    Reserved                                                    
   15 MQMD-ACCOUNTINGTOKEN   PIC X(32) VALUE LOW-VALUES.          
**    Reserved                                                    
   15 MQMD-APPLIDENTITYDATA  PIC X(32) VALUE SPACES.              
**    Reserved                                                    
   15 MQMD-PUTAPPLTYPE       PIC S9(9) BINARY  VALUE 0.           
**    Reserved                                                    
   15 MQMD-PUTAPPLNAME       PIC X(28) VALUE SPACES.              
**    Reserved                                                    
   15 MQMD-PUTDATE           PIC X(8) VALUE SPACES.               
**    Reserved                                                    
   15 MQMD-PUTTIME           PIC X(8) VALUE SPACES.               
**    Reserved                                                    
   15 MQMD-APPLORIGINDATA    PIC X(4) VALUE SPACES.               
                                                                  
                                                                  
 01  WS-PUT-OPTIONS.                                              
**   MQPMO structure                                              
  10 MQPMO.                                                       
**    Structure identifier                                        
   15 MQPMO-STRUCID           PIC X(4) VALUE 'PMO '.              
**    Structure version number                                    
   15 MQPMO-VERSION           PIC S9(9) BINARY   VALUE 1.         
**    Reserved                                                    
   15 MQPMO-OPTIONS           PIC S9(9) BINARY   VALUE 0.         
**    Reserved                                                    
   15 MQPMO-TIMEOUT           PIC S9(9) BINARY   VALUE -1.        
**    Reserved                                                    
   15 MQPMO-CONTEXT           PIC S9(9) BINARY   VALUE 0.         
**    Reserved                                                    
   15 MQPMO-KNOWNDESTCOUNT    PIC S9(9) BINARY   VALUE 0.         
**    Reserved                                                    
   15 MQPMO-UNKNOWNDESTCOUNT  PIC S9(9) BINARY   VALUE 0.         
**    Reserved                                                    
   15 MQPMO-INVALIDDESTCOUNT  PIC S9(9) BINARY   VALUE 0.         
**    Resolved name of destination queue                          
   15 MQPMO-RESOLVEDQNAME     PIC X(48) VALUE SPACES.             
**    Resolved name of destination queue manager                  
   15 MQPMO-RESOLVEDQMGRNAME  PIC X(48) VALUE SPACES.             
                                                                  
                                                                  
 01  WS-GET-OPTIONS.                                              
**   MQGMO structure                                              
  10 MQGMO.                                                       
**    Structure identifier                                        
   15 MQGMO-STRUCID        PIC X(4) VALUE 'GMO '.                 
**    Structure version number                                    
   15 MQGMO-VERSION        PIC S9(9) BINARY   VALUE 1.            
**    Options                                                     
   15 MQGMO-OPTIONS        PIC S9(9) BINARY   VALUE 0.            
**    Wait interval                                               
   15 MQGMO-WAITINTERVAL   PIC S9(9) BINARY   VALUE 0.            
**    Signal                                                      
   15 MQGMO-SIGNAL1        PIC S9(9) BINARY   VALUE 0.            
**    Reserved                                                    
   15 MQGMO-SIGNAL2        PIC S9(9) BINARY   VALUE 0.            
**    Resolved name of destination queue                          
   15 MQGMO-RESOLVEDQNAME  PIC X(48) VALUE SPACES.                
                                                                  
                                                                  
                                                                  
*---------------------------------------------------------------* 
 LINKAGE SECTION.                                                 
*---------------------------------------------------------------* 
                                                                  
 01  LK-DATA.                                                     
     05  FILLER                    PIC X.                         
*---------------------------------------------------------------* 
 PROCEDURE DIVISION.                                              
*---------------------------------------------------------------* 
                                                                  
 0000-MAIN-LINE.                                                  
                                                                  
*--Initialize by reading in the 3 possible parameters.            
     PERFORM 1000-INITIALIZE                                      
        THRU 1000-EXIT                                            
*--Connect to the QM                                              
     PERFORM 1500-CONN-QM                                         
        THRU 1500-EXIT                                            
*--Prepare the DLQ Source for processing                          
     PERFORM 2000-PREP-DLQ-SOURCE                                 
        THRU 2000-EXIT                                            
*--Prepare the DLQ Target for processing                          
     PERFORM 2500-PREP-DLQ-TARGET                                 
        THRU 2500-EXIT                                            
*--Process while there are still messages on the DLQ Source.      
     PERFORM 3000-GET-SOURCE-DLQ                                  
        THRU 3000-EXIT                                            
     PERFORM UNTIL (SRC-RCODE-VALUE = MQRC-NO-MSG-AVAILABLE)      
*-- Assume the MSG will be processed OK.                          
        SET MSG-PROCESSED-OK   TO TRUE                            
        PERFORM 4000-PROCESS-DLQ-MSG                              
           THRU 4000-EXIT                                         
        IF MSG-PROCESSED-OK THEN                                  
           PERFORM 3000-GET-SOURCE-DLQ                            
              THRU 3000-EXIT                                      
        END-IF                                                    
     END-PERFORM                                                  
*--Shutdown the DLQ Source                                        
     PERFORM 6000-SHUT-DLQ-SOURCE                                 
        THRU 6000-EXIT                                            
*--Shutdown the DLQ Target                                        
     PERFORM 6500-SHUT-DLQ-TARGET                                 
        THRU 6500-EXIT                                            
*--Disconnect from QM                                             
     PERFORM 7000-DISC-QM                                         
        THRU 7000-EXIT                                            
     .                                                            
                                                                  
*----------------------------------------------------------------*
 0000-RESTART.                                                    
*----------------------------------------------------------------*
*--If the user specified a delay time then schedule the task      
*--again using the same parameters.                               
                                                                  
*    EXEC CICS START                                              
*              TRANSID(WS-TRANSID)                                
*              FROM(WS-PASSED-INFO)                               
*              LENGTH(LENGTH OF WS-PASSED-INFO)                   
*              AFTER SECONDS(WS-DELAY)                            
*    END-EXEC                                                     
     CONTINUE                                                     
     .                                                            
*----------------------------------------------------------------*
 0000-RETURN.                                                     
                                                                  
     EXEC CICS RETURN                                             
     END-EXEC                                                     
     .                                                            
     GOBACK.                                                      
 0000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 1000-INITIALIZE.                                                 
*----------------------------------------------------------------*
* Purpose: Setup initial data areas and read parameters.          
*----------------------------------------------------------------*
*--Set up some condition handling                                 
     MOVE '1000-INITIALIZE'    TO ERROR-DEBUG-LOCATION            
     EXEC CICS HANDLE ABEND                                       
                      LABEL   (9900-ABEND-CONDITION)              
     END-EXEC                                                     
*--Some common conditions from the the EXEC CICS which are issued.
     EXEC CICS HANDLE CONDITION                                   
                      ENDDATA (9900-HANDLE-CONDITION)             
                      INVREQ  (9900-HANDLE-CONDITION)             
                      LENGERR (9900-HANDLE-CONDITION)             
                      NOTFND  (9900-HANDLE-CONDITION)             
                      NOTAUTH (9900-HANDLE-CONDITION)             
     END-EXEC                                                     
*--Get  CICS start code.                                          
     EXEC CICS ASSIGN                                             
                STARTCODE (WS-STARTCODE)                          
     END-EXEC                                                     
*                                                                 
*--Get input data dependent on start code.                        
     MOVE LENGTH OF WS-PASSED-INFO TO WS-PASS-MSG-LENGTH          
     IF  START-WITH-DATA THEN                                     
         EXEC CICS RETRIEVE                                       
                         INTO (WS-PASSED-INFO)                    
                       LENGTH (WS-PASS-MSG-LENGTH)                
         END-EXEC                                                 
*                                                                 
         UNSTRING WS-PASSED-INFO DELIMITED BY ALL SPACES INTO     
                  SOURCE-DLQ-NAME                                 
                  TARGET-DLQ-NAME                                 
                  WS-TIMEDELAY                                    
         END-UNSTRING                                             
      ELSE                                                        
         EXEC  CICS RECEIVE                                       
                         INTO   (WS-PASSED-INFO)                  
                         LENGTH (WS-PASS-MSG-LENGTH)              
         END-EXEC                                                 
                                                                  
*--EXTRACT THE VARIOUS OPTIONS                                    
         UNSTRING WS-PASSED-INFO DELIMITED BY ALL SPACES INTO     
                  WS-TRANSID                                      
                  SOURCE-DLQ-NAME                                 
                  TARGET-DLQ-NAME                                 
                  WS-TIMEDELAY                                    
         END-UNSTRING                                             
     END-IF                                                       
     INSPECT SOURCE-DLQ-NAME                                      
        REPLACING ALL LOW-VALUE BY SPACE                          
     INSPECT TARGET-DLQ-NAME                                      
        REPLACING ALL LOW-VALUE BY SPACE                          
*-- Prepare parameters in case of reSTART                         
     EXEC CICS BIF DEEDIT                                         
               FIELD(WS-TIMEDELAY)                                
               LENGTH(LENGTH OF WS-TIMEDELAY)                     
     END-EXEC                                                     
     MOVE WS-TIMEDELAYN TO WS-DELAY                               
     STRING SOURCE-DLQ-NAME                                       
            ' '                                                   
            TARGET-DLQ-NAME                                       
            ' '                                                   
            WS-TIMEDELAY DELIMITED BY SIZE                        
       INTO WS-PASSED-INFO                                        
     END-STRING                                                   
     .                                                            
 1000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 1500-CONN-QM.                                                    
*----------------------------------------------------------------*
* PURPOSE: CONNECT to the QM using default name.                  
*----------------------------------------------------------------*
*                                                                 
*--MQCONNECT TO QM                                                
     MOVE '1500-CONN-QM'       TO ERROR-DEBUG-LOCATION            
     MOVE  SPACES        TO   WS-QM-NAME-CONNECT                  
     MOVE MQCC-OK        TO   WS-HCONN-CCODE                      
     MOVE MQRC-NONE      TO   WS-HCONN-RCODE                      
     SET WS-HCONN-VALUE  TO   NULL                                
     CALL 'MQCONN'  USING     WS-QM-NAME-CONNECT                  
                              WS-HCONN-ADDR-AREA                  
                              WS-HCONN-CCODE                      
                              WS-HCONN-RCODE                      
     END-CALL                                                     
*                                                                 
     IF WS-HCONN-CCODE   NOT EQUAL  ZERO THEN                     
           MOVE 'CONN'          TO  WS-FUNCTION                   
           MOVE WS-HCONN-CCODE  TO  WS-ERR-DISPLAY-CCODE          
           MOVE WS-HCONN-RCODE  TO  WS-ERR-DISPLAY-RCODE          
           GO TO  9900-ERR-DISPLAY                                
*    END-IF                                                       
     .                                                            
 1500-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 2000-PREP-DLQ-SOURCE.                                            
*----------------------------------------------------------------*
*--PURPOSE: OPEN the SOURCE DLQ ready for receiving messages.     
*----------------------------------------------------------------*
                                                                  
     MOVE '2000-PREP-DLQ-S'    TO ERROR-DEBUG-LOCATION            
     MOVE MQOO-BROWSE      TO   SRC-Q-OPEN-OPTIONS-VALUE          
     MOVE MQCC-OK          TO   SRC-CCODE-VALUE                   
     MOVE MQRC-NONE        TO   SRC-RCODE-VALUE                   
     MOVE SPACES           TO   MQOD-OBJECTQMGRNAME               
     MOVE SOURCE-DLQ-NAME  TO   MQOD-OBJECTNAME                   
     SET SRC-HOBJ-VALUE    TO   NULL                              
     CALL 'MQOPEN'  USING       WS-HCONN-ADDR-AREA                
                                WS-Q-NAME-AREA                    
                                SRC-Q-OPEN-OPTIONS                
                                SRC-HOBJ-ADDR-AREA                
                                SRC-CCODE-ADDR-AREA               
                                SRC-RCODE-ADDR-AREA               
     END-CALL                                                     
*                                                                 
     IF SRC-CCODE-VALUE   NOT EQUAL  ZERO THEN                    
           MOVE 'OPEN'          TO  WS-FUNCTION                   
           MOVE SRC-CCODE-VALUE TO  WS-ERR-DISPLAY-CCODE          
           MOVE SRC-RCODE-VALUE TO  WS-ERR-DISPLAY-RCODE          
          GO TO  9900-ERR-DISPLAY                                 
     END-IF                                                       
     .                                                            
 2000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 2500-PREP-DLQ-TARGET.                                            
*----------------------------------------------------------------*
*--PURPOSE: OPEN the TARGET DLQ ready for outputing messages.     
*----------------------------------------------------------------*
                                                                  
     MOVE '2000-PREP-DLQ-T'    TO ERROR-DEBUG-LOCATION            
     MOVE MQOO-OUTPUT      TO   TGT-Q-OPEN-OPTIONS-VALUE          
     MOVE MQCC-OK          TO   TGT-CCODE-VALUE                   
     MOVE MQRC-NONE        TO   TGT-RCODE-VALUE                   
     MOVE SPACES           TO   MQOD-OBJECTQMGRNAME               
     MOVE TARGET-DLQ-NAME  TO   MQOD-OBJECTNAME                   
     SET TGT-HOBJ-VALUE    TO   NULL                              
     CALL 'MQOPEN'  USING       WS-HCONN-ADDR-AREA                
                                WS-Q-NAME-AREA                    
                                TGT-Q-OPEN-OPTIONS                
                                TGT-HOBJ-ADDR-AREA                
                                TGT-CCODE-ADDR-AREA               
                                TGT-RCODE-ADDR-AREA               
     END-CALL                                                     
*                                                                 
     IF TGT-CCODE-VALUE   NOT EQUAL  ZERO THEN                    
           MOVE 'OPEN'          TO  WS-FUNCTION                   
           MOVE TGT-CCODE-VALUE TO  WS-ERR-DISPLAY-CCODE          
           MOVE TGT-RCODE-VALUE TO  WS-ERR-DISPLAY-RCODE          
          GO TO  9900-ERR-DISPLAY                                 
     END-IF                                                       
     .                                                            
 2500-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 3000-GET-SOURCE-DLQ.                                             
*----------------------------------------------------------------*
* PURPOSE: GET one message from the SOURCE DLQ                    
*----------------------------------------------------------------*
*                                                                 
     MOVE '3000-GET-SOURCE'    TO ERROR-DEBUG-LOCATION            
     MOVE MQCC-OK    TO   SRC-CCODE-VALUE                         
     MOVE MQRC-NONE  TO   SRC-RCODE-VALUE                         
     MOVE LOW-VALUES TO   MQMD-MSGID                              
     MOVE LENGTH OF WS-DLQ-BUFFER                                 
                     TO   WS-DLQ-BUFFER-LEN                       
*                                                                 
     CALL 'MQGET'   USING  WS-HCONN-ADDR-AREA                     
                           SRC-HOBJ-ADDR-AREA                     
                           WS-MSG-DESCRIPTOR                      
                           WS-GET-OPTIONS                         
                           WS-DLQ-BUFFER-LEN                      
                           WS-DLQ-BUFFER                          
                           WS-DLQ-BUFFER-ACTUAL                   
                           SRC-CCODE-ADDR-AREA                    
                           SRC-RCODE-ADDR-AREA                    
     END-CALL                                                     
     IF SRC-RCODE-VALUE = MQRC-NO-MSG-AVAILABLE OR                
        (SRC-RCODE-VALUE = MQRC-NONE AND                          
         SRC-CCODE-VALUE = MQCC-OK)                               
      THEN                                                        
        EXEC CICS SYNCPOINT                                       
        END-EXEC                                                  
     ELSE                                                         
        MOVE 'GET'           TO  WS-FUNCTION                      
        MOVE SRC-CCODE-VALUE TO  WS-ERR-DISPLAY-CCODE             
        MOVE SRC-RCODE-VALUE TO  WS-ERR-DISPLAY-RCODE             
        GO TO  9900-ERR-DISPLAY                                   
     END-IF                                                       
*                                                                 
                                                                  
      .                                                           
 3000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 4000-PROCESS-DLQ-MSG.                                            
*----------------------------------------------------------------*
*--                                                               
*                                                                 
     MOVE '4000-PROCESS-DLQ'   TO ERROR-DEBUG-LOCATION            
     SET VALID-ACTUAL-QUEUE   TO TRUE                             
     PERFORM 8000-INQ-TARGET-QUEUENAME                            
        THRU 8000-EXIT                                            
     IF VALID-ACTUAL-QUEUE THEN                                   
        PERFORM 9000-PUT1-TO-ACTUAL-Q                             
           THRU 9000-EXIT                                         
     ELSE                                                         
        PERFORM 9500-PUT-TO-TARGET-DLQ                            
           THRU 9500-EXIT                                         
     END-IF                                                       
     .                                                            
 4000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 6000-SHUT-DLQ-SOURCE.                                            
*----------------------------------------------------------------*
*--MQCLOSE  for the SOURCE DLQ.                                   
*----------------------------------------------------------------*
*                                                                 
     MOVE '6000-SHUT-DLQ-S'    TO ERROR-DEBUG-LOCATION            
     MOVE  ZERO      TO   SRC-Q-OPEN-OPTIONS-VALUE                
     MOVE MQCC-OK    TO   SRC-CCODE-VALUE                         
     MOVE MQRC-NONE  TO   SRC-RCODE-VALUE                         
     CALL 'MQCLOSE' USING  WS-HCONN-ADDR-AREA                     
                           SRC-HOBJ-ADDR-AREA                     
                           SRC-Q-OPEN-OPTIONS                     
                           SRC-CCODE-ADDR-AREA                    
                           SRC-RCODE-ADDR-AREA                    
     END-CALL                                                     
*                                                                 
     IF SRC-CCODE-VALUE   NOT EQUAL  ZERO THEN                    
           MOVE 'CLOSE'         TO  WS-FUNCTION                   
           MOVE SRC-CCODE-VALUE TO  WS-ERR-DISPLAY-CCODE          
           MOVE SRC-RCODE-VALUE TO  WS-ERR-DISPLAY-RCODE          
           GO TO  9900-ERR-DISPLAY                                
     END-IF                                                       
     .                                                            
 6000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 6500-SHUT-DLQ-TARGET.                                            
*----------------------------------------------------------------*
*--MQCLOSE  for the TARGET DLQ.                                   
*----------------------------------------------------------------*
*                                                                 
     MOVE '6500-SHUT-DLQ-T'    TO ERROR-DEBUG-LOCATION            
     MOVE  ZERO      TO   TGT-Q-OPEN-OPTIONS-VALUE                
     MOVE MQCC-OK    TO   TGT-CCODE-VALUE                         
     MOVE MQRC-NONE  TO   TGT-RCODE-VALUE                         
     CALL 'MQCLOSE' USING  WS-HCONN-ADDR-AREA                     
                           TGT-HOBJ-ADDR-AREA                     
                           TGT-Q-OPEN-OPTIONS                     
                           TGT-CCODE-ADDR-AREA                    
                           TGT-RCODE-ADDR-AREA                    
     END-CALL                                                     
*                                                                 
     IF TGT-CCODE-VALUE   NOT EQUAL  ZERO THEN                    
           MOVE 'CLOSE'         TO  WS-FUNCTION                   
           MOVE TGT-CCODE-VALUE TO  WS-ERR-DISPLAY-CCODE          
           MOVE TGT-RCODE-VALUE TO  WS-ERR-DISPLAY-RCODE          
           GO TO  9900-ERR-DISPLAY                                
     END-IF                                                       
     .                                                            
 6500-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 7000-DISC-QM.                                                    
*----------------------------------------------------------------*
*--MQDISC  from the QM                                            
*----------------------------------------------------------------*
*                                                                 
     MOVE '7000-DISC-QM'       TO ERROR-DEBUG-LOCATION            
     MOVE MQCC-OK    TO    WS-HCONN-CCODE                         
     MOVE MQRC-NONE  TO    WS-HCONN-RCODE                         
     CALL 'MQDISC'  USING                                         
                           WS-HCONN-ADDR-AREA                     
                           WS-HCONN-CCODE                         
                           WS-HCONN-RCODE                         
     END-CALL                                                     
*                                                                 
     IF WS-HCONN-CCODE  NOT EQUAL  ZERO THEN                      
           MOVE 'MQDISC'        TO  WS-FUNCTION                   
           MOVE WS-HCONN-CCODE  TO  WS-ERR-DISPLAY-CCODE          
           MOVE WS-HCONN-RCODE  TO  WS-ERR-DISPLAY-RCODE          
           GO TO  9900-ERR-DISPLAY                                
     END-IF                                                       
     .                                                            
 7000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 8000-INQ-TARGET-QUEUENAME.                                       
*---------------------------------------------------------------- 
* PURPOSE: OPEN                                                   
*          INQ                                                    
*          CLOSE                                                  
*---------------------------------------------------------------- 
*                                                                 
*--MQOPEN   QUEUE TO QM                                           
     MOVE '8000-INQ-T'         TO ERROR-DEBUG-LOCATION            
      MOVE MQOO-INQUIRE   TO   INQ-Q-OPEN-OPTIONS-VALUE           
      MOVE SPACES         TO   MQOD-OBJECTQMGRNAME                
      MOVE SRC-DLQ-TARGET TO   MQOD-OBJECTNAME                    
      MOVE MQCC-OK        TO   INQ-CCODE-VALUE                    
      MOVE MQRC-NONE      TO   INQ-RCODE-VALUE                    
      SET INQ-HOBJ-VALUE  TO   NULL                               
      CALL 'MQOPEN'  USING  WS-HCONN-ADDR-AREA                    
                            WS-Q-NAME-AREA                        
                            INQ-Q-OPEN-OPTIONS                    
                            INQ-HOBJ-ADDR-AREA                    
                            INQ-CCODE-ADDR-AREA                   
                            INQ-RCODE-ADDR-AREA                   
      END-CALL                                                    
*                                                                 
      IF INQ-CCODE-VALUE   NOT EQUAL  ZERO THEN                   
          SET INVALID-ACTUAL-QUEUE TO TRUE                        
          GO TO 8000-EXIT                                         
      END-IF                                                      
*--SETUP INQ PARMS                                                
      MOVE MQIA-INHIBIT-PUT   TO MQI-SECTOR-ENTRY (1)             
      MOVE MQIA-Q-TYPE        TO MQI-SECTOR-ENTRY (2)             
      MOVE +2                 TO WS-SECTOR-COUNT                  
      MOVE LENGTH OF WS-CHAR-ATTR TO                              
                            WS-CHAR-ATTR-LENGTH                   
*                                                                 
*--MQPUT TO QUEUE TO QM                                           
      MOVE MQCC-OK    TO   INQ-CCODE-VALUE                        
      MOVE MQRC-NONE  TO   INQ-RCODE-VALUE                        
      CALL 'MQINQ'   USING    WS-HCONN-ADDR-AREA                  
                              INQ-HOBJ-ADDR-AREA                  
                              WS-SECTOR-COUNT                     
                              MQI-SECTOR                          
                              MQI-IN-ATTR-COUNT                   
                              MQI-IN-ATTR                         
                              MQI-CHAR-ATTR-LENGTH                
                              MQI-CHAR-ATTR                       
                              INQ-CCODE-ADDR-AREA                 
                              INQ-RCODE-ADDR-AREA                 
      END-CALL                                                    
*                                                                 
      IF INQ-CCODE-VALUE   NOT EQUAL  ZERO THEN                   
          SET INVALID-ACTUAL-QUEUE TO TRUE                        
          GO TO 8000-EXIT                                         
      END-IF                                                      
*                                                                 
*--MQCLOSE  QUEUE TO QM                                           
      MOVE  ZERO      TO   INQ-Q-OPEN-OPTIONS-VALUE               
      MOVE MQCC-OK    TO   INQ-CCODE-VALUE                        
      MOVE MQRC-NONE  TO   INQ-RCODE-VALUE                        
      CALL 'MQCLOSE' USING WS-HCONN-ADDR-AREA                     
                           INQ-HOBJ-ADDR-AREA                     
                           INQ-Q-OPEN-OPTIONS                     
                           INQ-CCODE-ADDR-AREA                    
                           INQ-RCODE-ADDR-AREA                    
      END-CALL                                                    
      .                                                           
 8000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 9000-PUT1-TO-ACTUAL-Q.                                           
*----------------------------------------------------------------*
*                                                                 
*--MQPUT1   QUEUE TO QM                                           
     MOVE '9000-PUT1-ACT'      TO ERROR-DEBUG-LOCATION            
       MOVE MQOO-OUTPUT    TO   MQPMO-OPTIONS                     
       MOVE SPACES         TO   MQOD-OBJECTQMGRNAME               
       MOVE SRC-DLQ-TARGET TO   MQOD-OBJECTNAME                   
       MOVE MQCC-OK        TO   INQ-CCODE-VALUE                   
       MOVE MQRC-NONE      TO   INQ-RCODE-VALUE                   
       COMPUTE WS-DLQ-OFFSET = LENGTH OF WS-DLQ-HEADER + 1        
       SUBTRACT LENGTH OF WS-DLQ-HEADER                           
             FROM WS-DLQ-BUFFER-ACTUAL                            
                 GIVING WS-DLQ-BUFFER-LEN                         
       CALL 'MQPUT1'  USING  WS-HCONN-ADDR-AREA                   
                             WS-Q-NAME-AREA                       
                             WS-MSG-DESCRIPTOR                    
                             WS-PUT-OPTIONS                       
                             WS-DLQ-BUFFER-LEN                    
               WS-DLQ-BUFFER(WS-DLQ-OFFSET:WS-DLQ-BUFFER-LEN)     
                             INQ-CCODE-ADDR-AREA                  
                             INQ-RCODE-ADDR-AREA                  
       END-CALL                                                   
*                                                                 
       IF INQ-CCODE-VALUE   NOT EQUAL  ZERO THEN                  
           MOVE 'MQPUT1'       TO  WS-FUNCTION                    
           MOVE INQ-CCODE-VALUE TO  WS-ERR-DISPLAY-CCODE          
           MOVE INQ-RCODE-VALUE TO  WS-ERR-DISPLAY-RCODE          
           GO TO  9900-ERR-DISPLAY                                
       END-IF                                                     
*                                                                 
       .                                                          
 9000-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 9500-PUT-TO-TARGET-DLQ.                                          
*----------------------------------------------------------------*
*                                                                 
*--MQPUT1   QUEUE TO QM                                           
     MOVE '9000-PUT-TARG'      TO ERROR-DEBUG-LOCATION            
       MOVE MQOO-OUTPUT    TO   MQPMO-OPTIONS                     
       MOVE SPACES         TO   MQOD-OBJECTQMGRNAME               
       MOVE TARGET-DLQ-NAME TO  MQOD-OBJECTNAME                   
       MOVE MQCC-OK        TO   TGT-CCODE-VALUE                   
       MOVE MQRC-NONE      TO   TGT-RCODE-VALUE                   
       MOVE WS-DLQ-BUFFER-ACTUAL                                  
                           TO WS-DLQ-BUFFER-LEN                   
       CALL 'MQPUT'   USING  WS-HCONN-ADDR-AREA                   
                             TGT-HOBJ-ADDR-AREA                   
                             WS-MSG-DESCRIPTOR                    
                             WS-PUT-OPTIONS                       
                             WS-DLQ-BUFFER-LEN                    
                             WS-DLQ-BUFFER                        
                             TGT-CCODE-ADDR-AREA                  
                             TGT-RCODE-ADDR-AREA                  
       END-CALL                                                   
*                                                                 
       IF TGT-CCODE-VALUE   NOT EQUAL  ZERO                       
        THEN                                                      
           MOVE 'MQPUT'         TO  WS-FUNCTION                   
           MOVE TGT-CCODE-VALUE TO  WS-ERR-DISPLAY-CCODE          
           MOVE TGT-RCODE-VALUE TO  WS-ERR-DISPLAY-RCODE          
           GO TO  9900-ERR-DISPLAY                                
       END-IF                                                     
*                                                                 
       .                                                          
 9500-EXIT.                                                       
     EXIT.                                                        
*----------------------------------------------------------------*
 9900-ERR-DISPLAY.                                                
*----------------------------------------------------------------*
*--Error in one of the called routines.                           
*                                                                 
                                                                  
     MOVE WS-ERR-DISPLAY1 TO WS-ERR-DISPLAY                       
     PERFORM 9999-PUT-TO-LOG-Q                                    
     MOVE WS-ERR-DISPLAY2 TO WS-ERR-DISPLAY                       
     PERFORM 9999-PUT-TO-LOG-Q                                    
     GO TO 0000-RETURN                                            
     .                                                            
 9900-ERR-EXIT.                                                   
     EXIT.                                                        
*----------------------------------------------------------------*
 9900-ABEND-CONDITION.                                            
*----------------------------------------------------------------*
     EXEC CICS ASSIGN                                             
               ABCODE(ERROR-DEBUG-ABEND)                          
     END-EXEC                                                     
     PERFORM 9999-CONVERT-ERROR-INFO                              
     MOVE WS-ERR-DISPLAY1 TO WS-ERR-DISPLAY                       
     PERFORM 9999-PUT-TO-LOG-Q                                    
     MOVE WS-ERR-DISPLAY3 TO WS-ERR-DISPLAY                       
     PERFORM 9999-PUT-TO-LOG-Q                                    
     GO TO 0000-RETURN                                            
     .                                                            
 9900-ABEND-EXIT.                                                 
     EXIT.                                                        
*----------------------------------------------------------------*
 9900-HANDLE-CONDITION.                                           
*----------------------------------------------------------------*
*--Unexpected CICS error.                                         
     PERFORM 9999-CONVERT-ERROR-INFO                              
     MOVE WS-ERR-DISPLAY1 TO WS-ERR-DISPLAY                       
     PERFORM 9999-PUT-TO-LOG-Q                                    
     MOVE WS-ERR-DISPLAY3 TO WS-ERR-DISPLAY                       
     PERFORM 9999-PUT-TO-LOG-Q                                    
     GO TO 0000-RETURN                                            
     .                                                            
 9900-HANDLE-EXIT.                                                
     EXIT.                                                        
*--------------------------------------------------------------*  
 9999-CONVERT-ERROR-INFO.                                         
*--------------------------------------------------------------*  
     MOVE EIBFN            TO ERROR-S-EIBFN                       
     MOVE ERROR-S-EIBFN-BIN  TO HEX-BINARY-WORD                   
     MOVE SPACES           TO HEX-CHAR-WORD                       
     PERFORM 9999-HEX-DIVIDE-BY-SIXTEEN                           
             VARYING HEX-INDX FROM 4 BY -1                        
             UNTIL   HEX-INDX < 1                                 
     MOVE HEX-CHAR-WORD    TO ERROR-DEBUG-EIBFN                   
                                                                  
     MOVE EIBRCODE         TO ERROR-S-EIBRCODE                    
                                                                  
     MOVE ERROR-S-EIBRCODE-B2 TO HEX-BINARY-WORD                  
                                                                  
     MOVE SPACES           TO HEX-CHAR-WORD                       
     PERFORM 9999-HEX-DIVIDE-BY-SIXTEEN                           
             VARYING HEX-INDX FROM 4 BY -1                        
             UNTIL   HEX-INDX < 1                                 
     MOVE HEX-CHAR-WORD    TO ERROR-DEBUG-EIBRCODE-1              
                                                                  
     MOVE ERROR-S-EIBRCODE-B4 TO HEX-BINARY-WORD                  
                                                                  
     MOVE SPACES           TO HEX-CHAR-WORD                       
     PERFORM 9999-HEX-DIVIDE-BY-SIXTEEN                           
             VARYING HEX-INDX FROM 8 BY -1                        
             UNTIL   HEX-INDX < 1                                 
                                                                  
     MOVE HEX-CHAR-WORD    TO ERROR-DEBUG-EIBRCODE-2              
                                                                  
     MOVE EIBRESP          TO ERROR-DEBUG-EIBRESP                 
     MOVE EIBRESP2         TO ERROR-DEBUG-EIBRESP2                
     .                                                            
 9999-CONVERT-EXIT.                                               
     EXIT.                                                        
                                                                  
 9999-HEX-DIVIDE-BY-SIXTEEN.                                      
     DIVIDE HEX-BINARY-WORD BY 16 GIVING HEX-BINARY-WORD          
         REMAINDER HEX-DIGIT-INDX                                 
     ADD +1 TO HEX-DIGIT-INDX                                     
     MOVE HEX-DIGIT (HEX-DIGIT-INDX) TO HEX-CHAR-BYTE(HEX-INDX)   
     .                                                            
 9999-HEX-EXIT.                                                   
     EXIT.                                                        
*----------------------------------------------------------------*
 9999-PUT-TO-LOG-Q.                                               
*----------------------------------------------------------------*
*                                                                 
*--MQPUT1   QUEUE TO QM                                           
       MOVE MQOO-OUTPUT    TO   MQPMO-OPTIONS                     
       MOVE SPACES         TO   MQOD-OBJECTQMGRNAME               
*-- The following line may be changed if the System Log name      
*-- has been altered.                                             
       MOVE 'SYSTEM.LOG'   TO   MQOD-OBJECTNAME                   
       MOVE MQCC-OK        TO   INQ-CCODE-VALUE                   
       MOVE MQRC-NONE      TO   INQ-RCODE-VALUE                   
       MOVE  LENGTH OF WS-ERR-DISPLAY                             
                           TO   WS-ERR-DISPLAY-LEN                
       CALL 'MQPUT1'  USING  WS-HCONN-ADDR-AREA                   
                             WS-Q-NAME-AREA                       
                             WS-MSG-DESCRIPTOR                    
                             WS-PUT-OPTIONS                       
                             WS-ERR-DISPLAY-LEN                   
                             WS-ERR-DISPLAY                       
                             INQ-CCODE-ADDR-AREA                  
                             INQ-RCODE-ADDR-AREA                  
       END-CALL                                                   
*                                                                 
       .                                                          
 9999-LOG-EXIT.                                                   
     EXIT.                                                        
*----------------------------------------------------------------*